//
//  AdvancedFilteringTechniquesViewController.swift
//  CoreImage
//
//  Created by Michael Gazzola on 3/29/15.
//  Copyright (c) 2015 Michael Gazzola. All rights reserved.
//

import CoreImage
import UIKit

class AdvancedFilteringTechniquesViewController: UIViewController {

    @IBOutlet var imageView: UIImageView!
    let image = UIImage(named: "img1.jpg")
    let context = CIContext(options: nil)
    
    // Creates a sepia tone.
    let sepia = CIFilter(name: "CISepiaTone")
    // Random noise. Takes no input.
    let random = CIFilter(name: "CIRandomGenerator")
    // Adjusts saturation, brightness, and contrast.
    let lighten = CIFilter(name: "CIColorControls")
    // Takes two inputs and blends them together based on brightness.
    let composite = CIFilter(name: "CIHardLightBlendMode")
    // Reduces peripheral brightness
    let vignette = CIFilter(name: "CIVignette")
    
    override func viewDidLoad() {
        super.viewDidLoad()
        self.createImageWithOldTimeEffectWithIntensity(0.5)
    }
    
    func createImageWithOldTimeEffectWithIntensity(intensity: Float) {
        if (intensity == 0) {
            self.imageView.image = self.image
            return
        }
        
        let image_ = CIImage(image: self.image)
        self.sepia.setValue(image_, forKey: kCIInputImageKey)
        self.sepia.setValue(intensity, forKey: kCIInputIntensityKey)
        
        self.lighten.setValue(self.random.outputImage, forKey: kCIInputImageKey)
        self.lighten.setValue(intensity, forKey: kCIInputBrightnessKey)
        self.lighten.setValue(0, forKey: kCIInputSaturationKey)
        
        let croppedImage = lighten.outputImage.imageByCroppingToRect(image_.extent())
        
        self.composite.setValue(self.sepia.outputImage, forKey: kCIInputImageKey)
        self.composite.setValue(croppedImage, forKey: kCIInputBackgroundImageKey)
        
        self.vignette.setValue(self.composite.outputImage, forKey: kCIInputImageKey)
        self.vignette.setValue(intensity * 2, forKey: kCIInputIntensityKey)
        self.vignette.setValue(intensity * 30, forKey: kCIInputRadiusKey)
        
        let cgImage = self.context.createCGImage(self.vignette.outputImage, fromRect: self.vignette.outputImage.extent())
        self.imageView.image = UIImage(CGImage: cgImage)
    }
    
    @IBAction func sliderValueDidChange(sender: UISlider) {
        self.createImageWithOldTimeEffectWithIntensity(sender.value)
    }
    
}
