//
//  FaceDetectionViewController.swift
//  CoreImage
//
//  Created by Michael Gazzola on 3/29/15.
//  Copyright (c) 2015 Michael Gazzola. All rights reserved.
//

import CoreImage
import UIKit

class FaceDetectionViewController: UIViewController, UINavigationControllerDelegate, UIImagePickerControllerDelegate {

    @IBOutlet var imageView: UIImageView!
    var image = UIImage(named: "img2.jpg")
    
    let context = CIContext(options: nil)
    let smileyView = UIView()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        self.imageView.image = self.image
        self.smileyView.frame = self.imageView.frame
    }
    
    @IBAction func detectFaces(sender: AnyObject) {
        self.smileyView.removeFromSuperview()
        self.smileyView.frame = self.imageView.frame
        
        // Set up the detector and grab the features.
        let image_ = CIImage(image: self.image)
        let detector = CIDetector(ofType: CIDetectorTypeFace, context: self.context,
                                  options: [CIDetectorAccuracy : CIDetectorAccuracyHigh])
        let features = detector.featuresInImage(image_)  // These are all the faces!
        
        // Need to scale by the image view, not the image.
        // The detector uses the image's scale (any x * y image) but we need
        // to scale it down to a (4:3 image).
        // This is going to look like poop if your image isn't 4:3 by the
        // way.
        let imgWidthScale = self.imageView.frame.size.width /
            self.image!.size.width
        let imgHeightScale = self.imageView.frame.size.height /
            self.image!.size.height
        
        for feature in features {
            var smileyImage = UIImage(named: "smiley.png")
            var smileyImageView = UIImageView(image: smileyImage)
            // Scale everything...
            var smileyOrigin = CGPoint(x: feature.bounds.origin.x * imgWidthScale,
                                       y: feature.bounds.origin.y  * imgHeightScale)
            var smileySize = CGSize(width: feature.bounds.size.width * imgWidthScale,
                                    height: feature.bounds.size.height * imgHeightScale)
            smileyImageView.frame = CGRect(origin: smileyOrigin, size: smileySize)
            // I hate CoreImage
            smileyImageView.transform = CGAffineTransformMakeScale(1, -1)
            self.smileyView.addSubview(smileyImageView)
        }
        // I hate CoreImage so much
        self.smileyView.transform = CGAffineTransformMakeScale(1, -1)
        self.view.addSubview(self.smileyView)
    }

    @IBAction func getNewPhoto(sender: UIButton) {
        let picker = UIImagePickerController()
        picker.delegate = self
        self.presentViewController(picker, animated: true, completion: nil)
    }
    
    func imagePickerController(picker: UIImagePickerController, didFinishPickingMediaWithInfo info: [NSObject : AnyObject]) {
        self.dismissViewControllerAnimated(true, completion: nil)
        
        let image = info[UIImagePickerControllerOriginalImage] as UIImage
        
        self.smileyView.removeFromSuperview()
        self.image = image
        self.imageView.image = image
    }

}
